==> dokuwiki_0.0.20061106.orig.tar.gz: dokuwiki-2006-11-06/inc/lang/lv/lang.php <==
<?php
/**
 * latvian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Aivars Miška <allefm@gmail.com>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Labot lapu';
$lang['btn_source'] = 'Parādīt lapas kodu';
$lang['btn_show']   = 'Parādīt lapu';
$lang['btn_create'] = 'Izveidot lapu';
$lang['btn_search'] = 'Meklēt';
$lang['btn_save']   = 'Saglabāt';
$lang['btn_preview']= 'Priekšskats';
$lang['btn_top']    = 'Atpakaļ uz sākumu';
$lang['btn_newer']  = '<< jaunāi';
$lang['btn_older']  = 'vecāi >>';
$lang['btn_revs']   = 'Vecās versijas';
$lang['btn_recent'] = 'Jaunākie grozījumi';
$lang['btn_upload'] = 'Augšupielādēt';
$lang['btn_cancel'] = 'Atlikt';
$lang['btn_index']  = 'Rādītājs';
$lang['btn_secedit']= 'Labot';
$lang['btn_login']  = 'Ieiet';
$lang['btn_logout'] = 'Iziet';
$lang['btn_admin']  = 'Administrēt';
$lang['btn_update'] = 'Atjaunot';
$lang['btn_delete'] = 'Dzēst';
$lang['btn_back']   = 'Atpakaļ';
$lang['btn_backlink']    = "Norādes uz lapu";
$lang['btn_backtomedia'] = 'Atpakaļ uz mēdiju failu izvēli';
$lang['btn_subscribe']   = 'Abonēt izmaiņu paziņojumus';
$lang['btn_unsubscribe'] = 'Atteikties no izmaiņu paziņojumiem';
$lang['btn_profile']    = 'Labot savu profilu';
$lang['btn_reset']     = 'Atsaukt izmaiņas';
$lang['btn_resendpwd'] = 'Nosūtīt jaunu paroli';
$lang['btn_draft']    = 'Labot melnrakstu';
$lang['btn_recover']  = 'Atjaunot melnrakstu';
$lang['btn_draftdel'] = 'Dzēst melnrakstu';

$lang['loggedinas'] = 'Pieteicies kā';
$lang['user']       = 'Lietotājvārds';
$lang['pass']       = 'Parole';
$lang['newpass']    = 'Jaunā parole';
$lang['oldpass']    = 'Atkārto patreizējo paroli';
$lang['passchk']    = 'vēlreiz';
$lang['remember']   = 'Atceries mani';
$lang['fullname']   = 'Pilns vārds';
$lang['email']      = 'E-pasts';
$lang['register']   = 'Reģistrēties';
$lang['profile']    = 'Lietotāja vārds';
$lang['badlogin']   = 'Atvaino, lietotājvārds vai parole aplama.';
$lang['draftdate']  = 'Melnraksts automātiski saglabāts'; // full dformat date will be added

$lang['regmissing'] = 'Atvaino, jāaizpilda visas ailes.';
$lang['reguexists'] = 'Atvaino, tāds lietājs jau ir.';
$lang['regsuccess'] = 'Lietotājs izveidots. Parole nosūtīta pa pastu.';
$lang['regsuccess2']= 'Lietotājs izveidots.';
$lang['regmailfail']= 'Šķiet, ka ir problēmas nosūtīt pastu. Lūdzu sazinies ar administratoru!';
$lang['regbadmail'] = 'Uzdotā epasta adrese izskatās aplama. Ja tas nav tiesa, sazinies ar administratoru.';
$lang['regbadpass'] = 'Abas ierakstītās paroles nav vienādas, lūduz atkārto.';
$lang['regpwmail']  = 'Tava DokuWiki parole';
$lang['reghere']    = 'Tev vēl nav sava konta? Izveido!';

$lang['profna']       = 'Labot profilu nav iespējams';
$lang['profnochange'] = 'Izmaiņu nav. Nav, ko darī.';
$lang['profnoempty']  = 'Bez vārda vai e-pasta adreses nevar.';
$lang['profchanged']  = 'Profils veiksmīgi izlabots.';

$lang['pwdforget'] = 'Aizmirsi paroli? Saņem jaunu';
$lang['resendna']  = 'Parolu izsutīšanu nepiedāvāju.';
$lang['resendpwd'] = 'Nosūtīt jaunu paroli lietotājam';
$lang['resendpwdmissing'] = 'Atvaino, jāizpilda visas ailes.';
$lang['resendpwdnouser']  = 'Atvaino, tāda lietotāja nav.';
$lang['resendpwdsuccess'] = 'Jaunā parole nosūtīta pa e-pastu.';
$lang['resendpwdbadauth'] = 'Atvaino, šis autorizācijas kods nav derīgs. Pārliecinies, ka lietoji pilnu apstiprināšanas adresi.';
$lang['resendpwdconfirm'] = 'Apstiprināšanas adrese nosūtīta pa epastu.';

$lang['txt_upload']   = 'Norādi augšupielādējamo failu';
$lang['txt_filename'] = 'Ievadi wikivārdu (nav obligāts)';
$lang['txt_overwrt']  = 'Aizstāt esošo failu';
$lang['lockedby']     = 'Patlaban bloķējis ';
$lang['lockexpire']   = 'Bloķējums beigsies ';
$lang['willexpire']   = 'Tavs bloķējums uz šo lapu pēc minūtes beigsies.\nLai izvairītos no konflikta, nospied Iepriekšapskata pogu\n un bloķējuma laiku sāks skaitīt no jauna.';

$lang['notsavedyet'] = 'Veiktas bet nav saglabātas izmaiņas.\nVai tiešām tās nevajag?';
$lang['rssfailed']   = 'Kļūda saņemot saturu no ';
$lang['nothingfound']= 'Nekas nav atrasts.';

$lang['mediaselect'] = 'Mēdiju faila izvēle';
$lang['fileupload']  = 'Mēdiju faila augšupielāde';
$lang['uploadsucc']  = 'Veiksmīgi ielādēts';
$lang['uploadfail']  = 'Ielādes kļūme. Varbūt aplamas tiesības?';
$lang['uploadwrong'] = 'Ielāde aizliegta. Neatļauts faila palšinājums';
$lang['uploadexist'] = 'Neko nedarīju, jo fails jau ir.';
$lang['deletesucc']  = 'Fails "%s" dzēsts.';
$lang['deletefail']  = 'Nevar dzēst "%s". Pārbaudi tiesības.';
$lang['mediainuse']  = 'Fails "%s" nav izdzēsts, to lieto.';
$lang['namespaces']  = 'Nodaļas';
$lang['mediafiles']  = 'Pieejamie faili';

$lang['js']['keepopen']    = 'Pēc faila izvēles logu paturēt atvērtu';
$lang['js']['hidedetails'] = 'Slēpt detaļas';
$lang['mediausage']  = 'Atsaucei uz failu lietot šādu sintaksi:';
$lang['mediaview']   = 'Skatīt oriģinālo failu';
$lang['mediaroot']   = 'sakne';
$lang['mediaupload'] = 'Augšupielādēt failu patreizējā sadaļā. Lai izveidotu dziļāku sadaļu, pieraksti to, atdalot ar kolu, pirms augšupielādējamā faila vārda.';
$lang['mediaextchange'] = 'Faila paplašinājums mainīts no .%s uz .%s!';

$lang['reference']   = 'Norādes uz failu';
$lang['ref_inuse']   = 'Failu nevar dzēst, jo izmanto šādas lapas:';
$lang['ref_hidden']  = 'Dažas norādes ir lapās, ko nav tiesibu skatīt';

$lang['hits']       = 'Apmeklējumi';
$lang['quickhits']  = 'Atbilstošās lapas';
$lang['toc']        = 'Satura rādītājs';
$lang['current']    = 'patlaban';
$lang['yours']      = 'Tava versija';
$lang['diff']       = 'atšķirības no patreizējas versijas';
$lang['line']       = 'Rinda';
$lang['breadcrumb'] = 'Ceļš';
$lang['youarehere'] = 'Tu atrodies šeit';
$lang['lastmod']    = 'Labota';
$lang['by']         = ', veicis';
$lang['deleted']    = 'dzēsts';
$lang['created']    = 'izveidots';
$lang['restored']   = 'vecā versija atjaunota';
$lang['summary']    = 'Anotācija';

$lang['mail_newpage'] = 'lapa pievienota:';
$lang['mail_changed'] = 'lapa mainīta:';
$lang['mail_new_user'] = 'Jauns lietotājs:';

$lang['nosmblinks'] = 'Saites uz Windows resursiem darbojas tikai Microsoft Internet Explorer.\nProtams, ka vari saiti kopēt un iespraust citā programmā.';

$lang['qb_alert']   = 'Lūdzu ieraksti formatējamo teku.\nTo pievienos dokumenta galā.';
$lang['qb_bold']    = 'Trekninājums';
$lang['qb_italic']  = 'Kursīvs';
$lang['qb_underl']  = 'Pasvītrojums';
$lang['qb_code']    = 'Vienplatuma burti';
$lang['qb_strike']  = 'Pārsvītrots teksts';
$lang['qb_h1']      = '1. līmeņa virsraksts';
$lang['qb_h2']      = '2. līmeņa virsraksts';
$lang['qb_h3']      = '3. līmeņa virsraksts';
$lang['qb_h4']      = '4. līmeņa virsraksts';
$lang['qb_h5']      = '5. līmeņa virsraksts';
$lang['qb_link']    = 'Iekšēja saite';
$lang['qb_extlink'] = 'Ārēja saite';
$lang['qb_hr']      = 'Horizontāla līnija';
$lang['qb_ol']      = 'Numurēts saraksts';
$lang['qb_ul']      = 'Nenumurēts saraksts';
$lang['qb_media']   = 'Pielikt attēlus un citus failus.';
$lang['qb_sig']     = 'Ievietot parakstu';
$lang['qb_smileys'] = 'Emotikoni';
$lang['qb_chars']   = 'Īpašās zīmes';

$lang['del_confirm']= 'Dzēst šo šķirkli?';
$lang['admin_register']= 'Pievienot jaunu lietotāju';

$lang['spell_start'] = 'Pārbaudīt pareizrakstību';
$lang['spell_stop']  = 'Turpināt labošanu';
$lang['spell_wait']  = 'Lūdzu uzgaidīt...';
$lang['spell_noerr'] = 'Kļūdu nav';
$lang['spell_nosug'] = 'Ieteikumu nav';
$lang['spell_change']= 'Aizstāt';

$lang['metaedit']    = 'Labot metadatus';
$lang['metasaveerr'] = 'Metadati nav saglabāti';
$lang['metasaveok']  = 'Metadati saglabāti';
$lang['img_backto']  = 'Atpakaļ uz';
$lang['img_title']   = 'Virsraksts';
$lang['img_caption'] = 'Apraksts';
$lang['img_date']    = 'Datums';
$lang['img_fname']   = 'Failvārds';
$lang['img_fsize']   = 'Izmērs';
$lang['img_artist']  = 'Fotogrāfs';
$lang['img_copyr']   = 'Autortiesības';
$lang['img_format']  = 'Formāts';
$lang['img_camera']  = 'Fotoaparāts';
$lang['img_keywords']= 'Atslēgvārdi';

$lang['subscribe_success']  = '%s pievienots  %s abonentu sarakstam';
$lang['subscribe_error']    = 'Kļūme pievienojot %s  %s abonentu sarakstam';
$lang['subscribe_noaddress']= 'Nav zināma adrese, ko pievienot abonentu sarakstam';
$lang['unsubscribe_success']= ' %s svītrots no %s abonentu saraksta';
$lang['unsubscribe_error']  = 'Kļūme svītrojot %s  no %s abonentu saraksta';

/* auth.class language support */
$lang['authmodfailed']   = 'Aplami konfigurēta lietotāju autentifikācija. Lūdzo ziņo Wiki administratoram.';
$lang['authtempfail']    = 'Lietotāju autentifikācija pašlaik nedarbojas. Ja tas turpinās ilgstoši, lūduz ziņo Wiki administratoram.';

/* installer strings */
$lang['i_chooselang'] = 'Izvēlies valodu';
$lang['i_installer']  = 'DokuWiki instalētājs';
$lang['i_wikiname']   = 'Wiki vārds';
$lang['i_enableacl']  = 'Lietot ACL (ieteikts)';
$lang['i_superuser']  = 'Superuser';
$lang['i_problems']   = 'Instalētājs atrada zemāk minētās problēmas. Kamēr tās nenovērš, nav iespējam turpināt.';
$lang['i_modified']   = 'Drošības nolūkos šis skripts darbosies tika ar jaunu nemodificētu Dokuwiki instalāciju.
                         Vai nu no jauna jāatarhifē fail ino lejupielādētās pakas vai jāraugās pēc padoma pilnā Dokuwiki instalācijas instrukcijā 
                         <a href="http://wiki.splitbrain.org/wiki:install"></a>';
$lang['i_writeerr']   = 'Nevar izveidot <code>%s</code>. Jāpārbauda direktorijas/faila tiesības un fails jāizveido pašam.'; 
$lang['i_confexists'] = '<code>%s</code> jau ir';
$lang['i_badhash']    = 'nepazīstams via izmainīts dokuwiki.php (hash=<code>%s</code>)';
$lang['i_badval']     = '<code>%s</code> - neatļauta vai tukša vērtība';
$lang['i_funcna']     = 'PHP funkcija <code>%s</code> nav pieejama. Varbūt jūsu servera īpašnieks to kāda iemesla dēļ atslēdzis?';
$lang['i_permfail']   = 'Dokuwiki nevar ierakstīt <code>%s</code>. Jālabo direktorijas tiesības!';
$lang['i_success']    = 'Konfigurēšana veiksmīgi pabeigta. Tagad vari nodzēst failu install.php. Tālā turpini <a href="doku.php">savā jaunajā DokuWiki</a>.';
$lang['i_failure']    = 'Rakstot konfigurācijas failu, gadījās dažas kļūmes. 
                         Pirms lieto <a href="doku.php">savu jauno DokuWiki</a>, tās varbūt jāizlabo.';
$lang['i_policy']     = 'Sākotnējā ACL politika';
$lang['i_pol0']       = 'Atvērts Wiki (raksta, lasa un augšupielādē ikviens)';
$lang['i_pol1']       = 'Publisks Wiki (lasa ikviens, raksta un augšupielādē reģistrēti lietotāji)';
$lang['i_pol2']       = 'Slēgts Wiki (raksta, lasa un augšupielādē tikai reģistrēti lietotāji)';
$lang['i_retry']      = 'Atkārtot';

//Setup VIM: ex: et ts=2 enc=utf-8 :

==> dokuwiki_0.0.20070626b.orig.tar.gz: dokuwiki-2007-06-26b/inc/lang/lv/lang.php <==
<?php
/**
 * latvian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Aivars Miška <allefm@gmail.com>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['doublequoteopening']  = '„';  // &bdquo; U+201E (8222)
$lang['doublequoteclosing']  = '“'; // &ldquo;  U+201C (8220)
$lang['singlequoteopening']  = '‚'; // &sbquo; U+201A (8218)
$lang['singlequoteclosing']  = '‘'; // &lsquo; U+2018 (8216)

$lang['btn_edit']   = 'Labot lapu';
$lang['btn_source'] = 'Parādīt lapas kodu';
$lang['btn_show']   = 'Parādīt lapu';
$lang['btn_create'] = 'Izveidot lapu';
$lang['btn_search'] = 'Meklēt';
$lang['btn_save']   = 'Saglabāt';
$lang['btn_preview']= 'Priekšskats';
$lang['btn_top']    = 'Atpakaļ uz sākumu';
$lang['btn_newer']  = '<< jaunāi';
$lang['btn_older']  = 'vecāi >>';
$lang['btn_revs']   = 'Vecās versijas';
$lang['btn_recent'] = 'Jaunākie grozījumi';
$lang['btn_upload'] = 'Augšupielādēt';
$lang['btn_cancel'] = 'Atlikt';
$lang['btn_index']  = 'Rādītājs';
$lang['btn_secedit']= 'Labot';
$lang['btn_login']  = 'Ieiet';
$lang['btn_logout'] = 'Iziet';
$lang['btn_admin']  = 'Administrēt';
$lang['btn_update'] = 'Atjaunot';
$lang['btn_delete'] = 'Dzēst';
$lang['btn_back']   = 'Atpakaļ';
$lang['btn_backlink']    = "Norādes uz lapu";
$lang['btn_backtomedia'] = 'Atpakaļ uz mēdiju failu izvēli';
$lang['btn_subscribe']   = 'Abonēt izmaiņu paziņojumus';
$lang['btn_unsubscribe'] = 'Atteikties no izmaiņu paziņojumiem';
$lang['btn_profile']    = 'Labot savu profilu';
$lang['btn_reset']     = 'Atsaukt izmaiņas';
$lang['btn_resendpwd'] = 'Nosūtīt jaunu paroli';
$lang['btn_draft']    = 'Labot melnrakstu';
$lang['btn_recover']  = 'Atjaunot melnrakstu';
$lang['btn_draftdel'] = 'Dzēst melnrakstu';

$lang['loggedinas'] = 'Pieteicies kā';
$lang['user']       = 'Lietotājvārds';
$lang['pass']       = 'Parole';
$lang['newpass']    = 'Jaunā parole';
$lang['oldpass']    = 'Atkārto patreizējo paroli';
$lang['passchk']    = 'vēlreiz';
$lang['remember']   = 'Atceries mani';
$lang['fullname']   = 'Pilns vārds';
$lang['email']      = 'E-pasts';
$lang['register']   = 'Reģistrēties';
$lang['profile']    = 'Lietotāja vārds';
$lang['badlogin']   = 'Atvaino, lietotājvārds vai parole aplama.';
$lang['draftdate']  = 'Melnraksts automātiski saglabāts'; // full dformat date will be added
$lang['minoredit']  = 'Sīkas izmaiņas';

$lang['regmissing'] = 'Atvaino, jāaizpilda visas ailes.';
$lang['reguexists'] = 'Atvaino, tāds lietājs jau ir.';
$lang['regsuccess'] = 'Lietotājs izveidots. Parole nosūtīta pa pastu.';
$lang['regsuccess2']= 'Lietotājs izveidots.';
$lang['regmailfail']= 'Šķiet, ka ir problēmas nosūtīt pastu. Lūdzu sazinies ar administratoru!';
$lang['regbadmail'] = 'Uzdotā epasta adrese izskatās aplama. Ja tas nav tiesa, sazinies ar administratoru.';
$lang['regbadpass'] = 'Abas ierakstītās paroles nav vienādas, lūduz atkārto.';
$lang['regpwmail']  = 'Tava DokuWiki parole';
$lang['reghere']    = 'Tev vēl nav sava konta? Izveido!';

$lang['profna']       = 'Labot profilu nav iespējams';
$lang['profnochange'] = 'Izmaiņu nav. Nav, ko darī.';
$lang['profnoempty']  = 'Bez vārda vai e-pasta adreses nevar.';
$lang['profchanged']  = 'Profils veiksmīgi izlabots.';

$lang['pwdforget'] = 'Aizmirsi paroli? Saņem jaunu';
$lang['resendna']  = 'Parolu izsutīšanu nepiedāvāju.';
$lang['resendpwd'] = 'Nosūtīt jaunu paroli lietotājam';
$lang['resendpwdmissing'] = 'Atvaino, jāizpilda visas ailes.';
$lang['resendpwdnouser']  = 'Atvaino, tāda lietotāja nav.';
$lang['resendpwdsuccess'] = 'Jaunā parole nosūtīta pa e-pastu.';
$lang['resendpwdbadauth'] = 'Atvaino, šis autorizācijas kods nav derīgs. Pārliecinies, ka lietoji pilnu apstiprināšanas adresi.';
$lang['resendpwdconfirm'] = 'Apstiprināšanas adrese nosūtīta pa epastu.';

$lang['txt_upload']   = 'Norādi augšupielādējamo failu';
$lang['txt_filename'] = 'Ievadi wikivārdu (nav obligāts)';
$lang['txt_overwrt']  = 'Aizstāt esošo failu';
$lang['lockedby']     = 'Patlaban bloķējis ';
$lang['lockexpire']   = 'Bloķējums beigsies ';
$lang['willexpire']   = 'Tavs bloķējums uz šo lapu pēc minūtes beigsies.\nLai izvairītos no konflikta, nospied Iepriekšapskata pogu\n un bloķējuma laiku sāks skaitīt no jauna.';

$lang['notsavedyet'] = 'Veiktas bet nav saglabātas izmaiņas.\nVai tiešām tās nevajag?';
$lang['rssfailed']   = 'Kļūda saņemot saturu no ';
$lang['nothingfound']= 'Nekas nav atrasts.';

$lang['mediaselect'] = 'Mēdiju faila izvēle';
$lang['fileupload']  = 'Mēdiju faila augšupielāde';
$lang['uploadsucc']  = 'Veiksmīgi ielādēts';
$lang['uploadfail']  = 'Ielādes kļūme. Varbūt aplamas tiesības?';
$lang['uploadwrong'] = 'Ielāde aizliegta. Neatļauts faila palšinājums';
$lang['uploadexist'] = 'Neko nedarīju, jo fails jau ir.';
$lang['deletesucc']  = 'Fails "%s" dzēsts.';
$lang['deletefail']  = 'Nevar dzēst "%s". Pārbaudi tiesības.';
$lang['mediainuse']  = 'Fails "%s" nav izdzēsts, to lieto.';
$lang['namespaces']  = 'Nodaļas';
$lang['mediafiles']  = 'Pieejamie faili';

$lang['js']['keepopen']    = 'Pēc faila izvēles logu paturēt atvērtu';
$lang['js']['hidedetails'] = 'Slēpt detaļas';
$lang['mediausage']  = 'Atsaucei uz failu lietot šādu sintaksi:';
$lang['mediaview']   = 'Skatīt oriģinālo failu';
$lang['mediaroot']   = 'sakne';
$lang['mediaupload'] = 'Augšupielādēt failu patreizējā sadaļā. Lai izveidotu dziļāku sadaļu, pieraksti to, atdalot ar kolu, pirms augšupielādējamā faila vārda.';
$lang['mediaextchange'] = 'Faila paplašinājums mainīts no .%s uz .%s!';
$lang['uploadbadcontent'] = 'Augšupielādētā saturs neatbilst faila paplašinājumam %s.';
$lang['uploadspam']  = 'Augšupielāde bloķēta ar melno sarakstu.';
$lang['uploadxss']   = 'Augšupielāde bloķēta iespējama slikta satura dēļ.';

$lang['reference']   = 'Norādes uz failu';
$lang['ref_inuse']   = 'Failu nevar dzēst, jo izmanto šādas lapas:';
$lang['ref_hidden']  = 'Dažas norādes ir lapās, ko nav tiesibu skatīt';

$lang['hits']       = 'Apmeklējumi';
$lang['quickhits']  = 'Atbilstošās lapas';
$lang['toc']        = 'Satura rādītājs';
$lang['current']    = 'patlaban';
$lang['yours']      = 'Tava versija';
$lang['diff']       = 'atšķirības no patreizējas versijas';
$lang['line']       = 'Rinda';
$lang['breadcrumb'] = 'Ceļš';
$lang['youarehere'] = 'Tu atrodies šeit';
$lang['lastmod']    = 'Labota';
$lang['by']         = ', veicis';
$lang['deleted']    = 'dzēsts';
$lang['created']    = 'izveidots';
$lang['restored']   = 'vecā versija atjaunota';
$lang['summary']    = 'Anotācija';

$lang['mail_newpage'] = 'lapa pievienota:';
$lang['mail_changed'] = 'lapa mainīta:';
$lang['mail_new_user'] = 'Jauns lietotājs:';
$lang['mail_upload']   = 'augšupielādētais fails:';

$lang['nosmblinks'] = 'Saites uz Windows resursiem darbojas tikai Microsoft Internet Explorer.\nProtams, ka vari saiti kopēt un iespraust citā programmā.';

$lang['qb_alert']   = 'Lūdzu ieraksti formatējamo teku.\nTo pievienos dokumenta galā.';
$lang['qb_bold']    = 'Trekninājums';
$lang['qb_italic']  = 'Kursīvs';
$lang['qb_underl']  = 'Pasvītrojums';
$lang['qb_code']    = 'Vienplatuma burti';
$lang['qb_strike']  = 'Pārsvītrots teksts';
$lang['qb_h1']      = '1. līmeņa virsraksts';
$lang['qb_h2']      = '2. līmeņa virsraksts';
$lang['qb_h3']      = '3. līmeņa virsraksts';
$lang['qb_h4']      = '4. līmeņa virsraksts';
$lang['qb_h5']      = '5. līmeņa virsraksts';
$lang['qb_link']    = 'Iekšēja saite';
$lang['qb_extlink'] = 'Ārēja saite';
$lang['qb_hr']      = 'Horizontāla līnija';
$lang['qb_ol']      = 'Numurēts saraksts';
$lang['qb_ul']      = 'Nenumurēts saraksts';
$lang['qb_media']   = 'Pielikt attēlus un citus failus.';
$lang['qb_sig']     = 'Ievietot parakstu';
$lang['qb_smileys'] = 'Emotikoni';
$lang['qb_chars']   = 'Īpašās zīmes';

$lang['del_confirm']= 'Dzēst šo šķirkli?';
$lang['admin_register']= 'Pievienot jaunu lietotāju';

$lang['spell_start'] = 'Pārbaudīt pareizrakstību';
$lang['spell_stop']  = 'Turpināt labošanu';
$lang['spell_wait']  = 'Lūdzu uzgaidīt...';
$lang['spell_noerr'] = 'Kļūdu nav';
$lang['spell_nosug'] = 'Ieteikumu nav';
$lang['spell_change']= 'Aizstāt';

$lang['metaedit']    = 'Labot metadatus';
$lang['metasaveerr'] = 'Metadati nav saglabāti';
$lang['metasaveok']  = 'Metadati saglabāti';
$lang['img_backto']  = 'Atpakaļ uz';
$lang['img_title']   = 'Virsraksts';
$lang['img_caption'] = 'Apraksts';
$lang['img_date']    = 'Datums';
$lang['img_fname']   = 'Failvārds';
$lang['img_fsize']   = 'Izmērs';
$lang['img_artist']  = 'Fotogrāfs';
$lang['img_copyr']   = 'Autortiesības';
$lang['img_format']  = 'Formāts';
$lang['img_camera']  = 'Fotoaparāts';
$lang['img_keywords']= 'Atslēgvārdi';

$lang['subscribe_success']  = '%s pievienots  %s abonentu sarakstam';
$lang['subscribe_error']    = 'Kļūme pievienojot %s  %s abonentu sarakstam';
$lang['subscribe_noaddress']= 'Nav zināma adrese, ko pievienot abonentu sarakstam';
$lang['unsubscribe_success']= ' %s svītrots no %s abonentu saraksta';
$lang['unsubscribe_error']  = 'Kļūme svītrojot %s  no %s abonentu saraksta';

/* auth.class language support */
$lang['authmodfailed']   = 'Aplami konfigurēta lietotāju autentifikācija. Lūdzo ziņo Wiki administratoram.';
$lang['authtempfail']    = 'Lietotāju autentifikācija pašlaik nedarbojas. Ja tas turpinās ilgstoši, lūduz ziņo Wiki administratoram.';

/* installer strings */
$lang['i_chooselang'] = 'Izvēlies valodu';
$lang['i_installer']  = 'DokuWiki instalētājs';
$lang['i_wikiname']   = 'Wiki vārds';
$lang['i_enableacl']  = 'Lietot ACL (ieteikts)';
$lang['i_superuser']  = 'Superuser';
$lang['i_problems']   = 'Instalētājs atrada zemāk minētās problēmas. Kamēr tās nenovērš, nav iespējam turpināt.';
$lang['i_modified']   = 'Drošības nolūkos šis skripts darbosies tika ar jaunu nemodificētu Dokuwiki instalāciju.
                         Vai nu no jauna jāatarhifē fail ino lejupielādētās pakas vai jāraugās pēc padoma pilnā Dokuwiki instalācijas instrukcijā 
                         <a href="http://wiki.splitbrain.org/wiki:install"></a>';
$lang['i_writeerr']   = 'Nevar izveidot <code>%s</code>. Jāpārbauda direktorijas/faila tiesības un fails jāizveido pašam.'; 
$lang['i_confexists'] = '<code>%s</code> jau ir';
$lang['i_badhash']    = 'nepazīstams via izmainīts dokuwiki.php (hash=<code>%s</code>)';
$lang['i_phpver']     = 'Jūsu PHP versija <code>%s</code> ir par vecu. Vajag versiju <code>%s</code>. Atjaunojiet savu PHP instalāciju.';
$lang['i_badval']     = '<code>%s</code> - neatļauta vai tukša vērtība';
$lang['i_funcna']     = 'PHP funkcija <code>%s</code> nav pieejama. Varbūt jūsu servera īpašnieks to kāda iemesla dēļ atslēdzis?';
$lang['i_permfail']   = 'Dokuwiki nevar ierakstīt <code>%s</code>. Jālabo direktorijas tiesības!';
$lang['i_success']    = 'Konfigurēšana veiksmīgi pabeigta. Tagad vari nodzēst failu install.php. Tālā turpini <a href="doku.php">savā jaunajā DokuWiki</a>.';
$lang['i_failure']    = 'Rakstot konfigurācijas failu, gadījās dažas kļūmes. 
                         Pirms lieto <a href="doku.php">savu jauno DokuWiki</a>, tās varbūt jāizlabo.';
$lang['i_policy']     = 'Sākotnējā ACL politika';
$lang['i_pol0']       = 'Atvērts Wiki (raksta, lasa un augšupielādē ikviens)';
$lang['i_pol1']       = 'Publisks Wiki (lasa ikviens, raksta un augšupielādē reģistrēti lietotāji)';
$lang['i_pol2']       = 'Slēgts Wiki (raksta, lasa un augšupielādē tikai reģistrēti lietotāji)';
$lang['i_retry']      = 'Atkārtot';

//Setup VIM: ex: et ts=2 enc=utf-8 :
